@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from anytraverse import typing as anyt
+from anytraverse.utils import _typing as anyt
 
 
 class BaseAttentionMapping[TInputMap, TPrompt, TOutputMap](ABC):
