@@ -1,13 +1,12 @@
 import torch
 from torch.nn import functional as F
-from PIL import Image as PILImage
-from transformers import AutoTokenizer, AutoModel, AutoImageProcessor
-from anytraverse.utils.base.encoding import ImageEncoder
-from anytraverse import typing as anyt
+from transformers import AutoModel, AutoImageProcessor
+from anytraverse.utils.base.encoding import HuggingFaceImageEncoder
+from anytraverse.utils import _typing as anyt
 from anytraverse.helpers.device import DEVICE
 
 
-class NomicImageEncoder[TImage: anyt.Image](ImageEncoder[TImage]):
+class NomicImageEncoder[TImage: anyt.Image](HuggingFaceImageEncoder[TImage]):
     """
     Nomic image encoding model
     """
@@ -15,18 +14,22 @@ class NomicImageEncoder[TImage: anyt.Image](ImageEncoder[TImage]):
     DIM = 768
 
     def __init__(self, device: torch.device = DEVICE) -> None:
-        super().__init__()
-        self._processor = AutoImageProcessor.from_pretrained(
-            "nomic-ai/nomic-embed-vision-v1.5",
-            use_fast=True,
+        super().__init__(
+            model_name="nomic-ai/nomic-embed-vision-v1.5",
+            device=device,
             cache_dir="data/weights/nomic",
         )
+        self._processor = AutoImageProcessor.from_pretrained(
+            self._model_name,
+            use_fast=self._use_fast_processor,
+            cache_dir=self._cache_dir,
+        )
         self._model = AutoModel.from_pretrained(
-            "nomic-ai/nomic-embed-vision-v1.5",
+            self._model_name,
             trust_remote_code=True,
-            cache_dir="data/weights/nomic",
-        ).to(device=device)
-        self._device = device
+            cache_dir=self._cache_dir,
+            device_map=self._device,
+        )
 
     def __call__(self, x: TImage | list[TImage]) -> anyt.Encoding:
         inputs = self._processor(x, return_tensors="pt").to(device=self._device)
